==> open-xchange-core_6.22.0.orig.tar.bz2: open-xchange-core-6.22.0/com.openexchange.data.conversion.ical.ical4j/src/com/openexchange/data/conversion/ical/ical4j/internal/FreeBusyConverters.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.data.conversion.ical.ical4j.internal;

import java.util.ArrayList;
import java.util.List;

import net.fortuna.ical4j.model.component.VFreeBusy;

import com.openexchange.data.conversion.ical.FreeBusyInformation;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.CreatedAndDTStamp;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.CreatedBy;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.End;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.Participants;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.Start;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.Uid;
import com.openexchange.data.conversion.ical.ical4j.internal.freebusy.FreeBusySlots;
import com.openexchange.data.conversion.ical.ical4j.internal.freebusy.FreeBusyAttendee;

/**
 * {@link FreeBusyConverters}
 * 
 * @author Tobias Friedrich <tobias.friedrich@open-xchange.com>
 */
public final class FreeBusyConverters {

    public static final List<AttributeConverter<VFreeBusy, FreeBusyInformation>> REQUEST;
    public static final List<AttributeConverter<VFreeBusy, FreeBusyInformation>> REPLY;

    private static AttributeConverter<VFreeBusy, FreeBusyInformation> uid = new Uid<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> createdAndDTStamp = new CreatedAndDTStamp<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> start = new Start<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> end = new End<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> participants = new Participants<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> freeBusyAttendee = new FreeBusyAttendee<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> freeBusySlots = new FreeBusySlots<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> createdBy = new CreatedBy<VFreeBusy, FreeBusyInformation>();
    
    /**
     * Prevent instantiation.
     */
    private FreeBusyConverters() {
        super();
    }

    static {
        REQUEST = getRequest();
        REPLY = getReply();
    }

    private static List<AttributeConverter<VFreeBusy, FreeBusyInformation>> getRequest() {
        List<AttributeConverter<VFreeBusy, FreeBusyInformation>> tmp = new ArrayList<AttributeConverter<VFreeBusy, FreeBusyInformation>>();
        tmp.add(start);
        tmp.add(end);
        tmp.add(uid);
        tmp.add(createdBy);
        tmp.add(createdAndDTStamp);
        tmp.add(participants);
        return tmp;
    }

    private static List<AttributeConverter<VFreeBusy, FreeBusyInformation>> getReply() {
        List<AttributeConverter<VFreeBusy, FreeBusyInformation>> tmp = new ArrayList<AttributeConverter<VFreeBusy, FreeBusyInformation>>();
        tmp.add(start);
        tmp.add(end);
        tmp.add(uid);
        tmp.add(createdBy);
        tmp.add(createdAndDTStamp);
        tmp.add(freeBusyAttendee);
        tmp.add(freeBusySlots);
        return tmp;
    }

}

==> open-xchange-core_7.2.2.orig.tar.bz2: open-xchange-core-7.2.2/com.openexchange.data.conversion.ical.ical4j/src/com/openexchange/data/conversion/ical/ical4j/internal/FreeBusyConverters.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.data.conversion.ical.ical4j.internal;

import java.util.ArrayList;
import java.util.List;
import net.fortuna.ical4j.model.component.VFreeBusy;
import com.openexchange.data.conversion.ical.FreeBusyInformation;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.CreatedAndDTStamp;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.CreatedBy;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.End;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.Start;
import com.openexchange.data.conversion.ical.ical4j.internal.calendar.Uid;
import com.openexchange.data.conversion.ical.ical4j.internal.freebusy.FreeBusyAttendee;
import com.openexchange.data.conversion.ical.ical4j.internal.freebusy.FreeBusyAttendees;
import com.openexchange.data.conversion.ical.ical4j.internal.freebusy.FreeBusySlots;

/**
 * {@link FreeBusyConverters}
 *
 * @author Tobias Friedrich <tobias.friedrich@open-xchange.com>
 */
public final class FreeBusyConverters {

    public static final List<AttributeConverter<VFreeBusy, FreeBusyInformation>> REQUEST;
    public static final List<AttributeConverter<VFreeBusy, FreeBusyInformation>> REPLY;

    private static AttributeConverter<VFreeBusy, FreeBusyInformation> uid = new Uid<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> createdAndDTStamp = new CreatedAndDTStamp<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> start = new Start<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> end = new End<VFreeBusy, FreeBusyInformation>();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> freeBusyAttendee = new FreeBusyAttendee();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> freeBusyAttendees = new FreeBusyAttendees();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> freeBusySlots = new FreeBusySlots();
    private static AttributeConverter<VFreeBusy, FreeBusyInformation> createdBy = new CreatedBy<VFreeBusy, FreeBusyInformation>();

    /**
     * Prevent instantiation.
     */
    private FreeBusyConverters() {
        super();
    }

    static {
        REQUEST = getRequest();
        REPLY = getReply();
    }

    private static List<AttributeConverter<VFreeBusy, FreeBusyInformation>> getRequest() {
        List<AttributeConverter<VFreeBusy, FreeBusyInformation>> tmp = new ArrayList<AttributeConverter<VFreeBusy, FreeBusyInformation>>();
        tmp.add(start);
        tmp.add(end);
        tmp.add(uid);
        tmp.add(createdBy);
        tmp.add(createdAndDTStamp);
        tmp.add(freeBusyAttendees);
        return tmp;
    }

    private static List<AttributeConverter<VFreeBusy, FreeBusyInformation>> getReply() {
        List<AttributeConverter<VFreeBusy, FreeBusyInformation>> tmp = new ArrayList<AttributeConverter<VFreeBusy, FreeBusyInformation>>();
        tmp.add(start);
        tmp.add(end);
        tmp.add(uid);
        tmp.add(createdBy);
        tmp.add(createdAndDTStamp);
        tmp.add(freeBusyAttendee);
        tmp.add(freeBusySlots);
        return tmp;
    }

}
